package Tapper::CLI;
# git description: v4.1.6-1-g403a6db

our $AUTHORITY = 'cpan:TAPPER';
# ABSTRACT: Tapper - tapper-* commandline tools
$Tapper::CLI::VERSION = '4.1.7';
use warnings;
use strict;

1; # End of Tapper::CLI

__END__

=pod

=encoding UTF-8

=head1 NAME

Tapper::CLI - Tapper - tapper-* commandline tools

=head1 AUTHOR

AMD OSRC Tapper Team <tapper@amd64.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2015 by Advanced Micro Devices, Inc..

This is free software, licensed under:

  The (two-clause) FreeBSD License

=cut
